@@ -44,6 +44,15 @@ use strict;
 
 =cut
 
+sub new {
+    my $class = shift;
+    my $self  = {};
+    my $stat;
+    bless( $self, $class );
+    $self->_init(@_);
+    return $self;
+}
+
 sub _init {
     my $self = shift;
     return $self->init(@_);
